@@ -28,6 +28,9 @@ parser.add_argument("-n", "--new-file", action="store", dest="filepath", help="C
 # make config.ini template file
 parser.add_argument("-ct", "--config-temp", action="store_true", dest="configtemp", help="Create template of config.ini file.")
 
+# deploy application
+parser.add_argument("-d", "--deploy", action="store_true", dest="deploy", help="Deploy your application")
+
 args = parser.parse_args()
 if len(sys.argv) == 1:
 	parser.parse_args(["./gaeinit.py", "-h"])
